import { z } from 'zod';
export declare const iConfigurationFilterSchema: z.ZodObject<{
    name: z.ZodString;
    customFieldName: z.ZodOptional<z.ZodString>;
    operator: z.ZodOptional<z.ZodLiteral<"not">>;
    options: z.ZodUnion<[z.ZodArray<z.ZodString>, z.ZodNull]>;
}, "strip", z.ZodTypeAny, {
    customFieldName?: string | undefined;
    operator?: "not" | undefined;
    name: string;
    options: string[] | null;
}, {
    customFieldName?: string | undefined;
    operator?: "not" | undefined;
    name: string;
    options: string[] | null;
}>;
export declare const iProductSkuAndApplicationSchema: z.ZodObject<{
    sku: z.ZodString;
    application: z.ZodString;
}, "strip", z.ZodTypeAny, {
    application: string;
    sku: string;
}, {
    application: string;
    sku: string;
}>;
export declare const iFavoriteProductSkuAndApplicationSchema: z.ZodObject<{
    product: z.ZodObject<{
        sku: z.ZodString;
        application: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        application: string;
        sku: string;
    }, {
        application: string;
        sku: string;
    }>;
}, "strip", z.ZodTypeAny, {
    product: {
        application: string;
        sku: string;
    };
}, {
    product: {
        application: string;
        sku: string;
    };
}>;
export declare const iFacetSchema: z.ZodObject<{
    name: z.ZodString;
    options: z.ZodUnion<[z.ZodArray<z.ZodString>, z.ZodNull]>;
}, "strip", z.ZodTypeAny, {
    name: string;
    options: string[] | null;
}, {
    name: string;
    options: string[] | null;
}>;
export declare const iProductSchema: z.ZodObject<{
    sku: z.ZodString;
    name: z.ZodOptional<z.ZodString>;
    title: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    application: z.ZodString;
    image: z.ZodString;
    price: z.ZodOptional<z.ZodString>;
    facets: z.ZodOptional<z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        options: z.ZodUnion<[z.ZodArray<z.ZodString>, z.ZodNull]>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        options: string[] | null;
    }, {
        name: string;
        options: string[] | null;
    }>>>;
    _id: z.ZodString;
}, "strip", z.ZodTypeAny, {
    description?: string | undefined;
    name?: string | undefined;
    price?: string | undefined;
    facets?: {
        name: string;
        options: string[] | null;
    }[] | undefined;
    application: string;
    sku: string;
    title: string;
    image: string;
    _id: string;
}, {
    description?: string | undefined;
    name?: string | undefined;
    price?: string | undefined;
    facets?: {
        name: string;
        options: string[] | null;
    }[] | undefined;
    application: string;
    sku: string;
    title: string;
    image: string;
    _id: string;
}>;
export declare const iFavoriteSchema: z.ZodObject<{
    product: z.ZodObject<{
        sku: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
        title: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        application: z.ZodString;
        image: z.ZodString;
        price: z.ZodOptional<z.ZodString>;
        facets: z.ZodOptional<z.ZodArray<z.ZodObject<{
            name: z.ZodString;
            options: z.ZodUnion<[z.ZodArray<z.ZodString>, z.ZodNull]>;
        }, "strip", z.ZodTypeAny, {
            name: string;
            options: string[] | null;
        }, {
            name: string;
            options: string[] | null;
        }>>>;
        _id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        description?: string | undefined;
        name?: string | undefined;
        price?: string | undefined;
        facets?: {
            name: string;
            options: string[] | null;
        }[] | undefined;
        application: string;
        sku: string;
        title: string;
        image: string;
        _id: string;
    }, {
        description?: string | undefined;
        name?: string | undefined;
        price?: string | undefined;
        facets?: {
            name: string;
            options: string[] | null;
        }[] | undefined;
        application: string;
        sku: string;
        title: string;
        image: string;
        _id: string;
    }>;
}, "strip", z.ZodTypeAny, {
    product: {
        description?: string | undefined;
        name?: string | undefined;
        price?: string | undefined;
        facets?: {
            name: string;
            options: string[] | null;
        }[] | undefined;
        application: string;
        sku: string;
        title: string;
        image: string;
        _id: string;
    };
}, {
    product: {
        description?: string | undefined;
        name?: string | undefined;
        price?: string | undefined;
        facets?: {
            name: string;
            options: string[] | null;
        }[] | undefined;
        application: string;
        sku: string;
        title: string;
        image: string;
        _id: string;
    };
}>;
export declare const iSceneSubSelectionSchema: z.ZodObject<{
    name: z.ZodString;
    title: z.ZodOptional<z.ZodString>;
    previewImage: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    title?: string | undefined;
    previewImage?: string | undefined;
    name: string;
}, {
    title?: string | undefined;
    previewImage?: string | undefined;
    name: string;
}>;
export declare const iConfigurationSceneCommonSchema: z.ZodObject<{
    title: z.ZodString;
    subtitle: z.ZodOptional<z.ZodString>;
    previewImage: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    subtitle?: string | undefined;
    previewImage?: string | undefined;
    title: string;
}, {
    subtitle?: string | undefined;
    previewImage?: string | undefined;
    title: string;
}>;
export declare const iConfigurationSceneOutputSchema: z.ZodIntersection<z.ZodObject<{
    title: z.ZodString;
    subtitle: z.ZodOptional<z.ZodString>;
    previewImage: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    subtitle?: string | undefined;
    previewImage?: string | undefined;
    title: string;
}, {
    subtitle?: string | undefined;
    previewImage?: string | undefined;
    title: string;
}>, z.ZodObject<{
    name: z.ZodString;
    subSelection: z.ZodOptional<z.ZodObject<{
        name: z.ZodString;
        title: z.ZodOptional<z.ZodString>;
        previewImage: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        title?: string | undefined;
        previewImage?: string | undefined;
        name: string;
    }, {
        title?: string | undefined;
        previewImage?: string | undefined;
        name: string;
    }>>;
}, "strip", z.ZodTypeAny, {
    subSelection?: {
        title?: string | undefined;
        previewImage?: string | undefined;
        name: string;
    } | undefined;
    name: string;
}, {
    subSelection?: {
        title?: string | undefined;
        previewImage?: string | undefined;
        name: string;
    } | undefined;
    name: string;
}>>;
export declare const iSceneSchema: z.ZodIntersection<z.ZodIntersection<z.ZodObject<{
    title: z.ZodString;
    subtitle: z.ZodOptional<z.ZodString>;
    previewImage: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    subtitle?: string | undefined;
    previewImage?: string | undefined;
    title: string;
}, {
    subtitle?: string | undefined;
    previewImage?: string | undefined;
    title: string;
}>, z.ZodObject<{
    name: z.ZodString;
    subSelection: z.ZodOptional<z.ZodObject<{
        name: z.ZodString;
        title: z.ZodOptional<z.ZodString>;
        previewImage: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        title?: string | undefined;
        previewImage?: string | undefined;
        name: string;
    }, {
        title?: string | undefined;
        previewImage?: string | undefined;
        name: string;
    }>>;
}, "strip", z.ZodTypeAny, {
    subSelection?: {
        title?: string | undefined;
        previewImage?: string | undefined;
        name: string;
    } | undefined;
    name: string;
}, {
    subSelection?: {
        title?: string | undefined;
        previewImage?: string | undefined;
        name: string;
    } | undefined;
    name: string;
}>>, z.ZodObject<{
    experienceId: z.ZodString;
    sceneId: z.ZodString;
}, "strip", z.ZodTypeAny, {
    experienceId: string;
    sceneId: string;
}, {
    experienceId: string;
    sceneId: string;
}>>;
export declare const iFavoriteSceneSchema: z.ZodObject<{
    id: z.ZodString;
    image: z.ZodString;
    favorites: z.ZodArray<z.ZodObject<{
        product: z.ZodObject<{
            sku: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
            title: z.ZodString;
            description: z.ZodOptional<z.ZodString>;
            application: z.ZodString;
            image: z.ZodString;
            price: z.ZodOptional<z.ZodString>;
            facets: z.ZodOptional<z.ZodArray<z.ZodObject<{
                name: z.ZodString;
                options: z.ZodUnion<[z.ZodArray<z.ZodString>, z.ZodNull]>;
            }, "strip", z.ZodTypeAny, {
                name: string;
                options: string[] | null;
            }, {
                name: string;
                options: string[] | null;
            }>>>;
            _id: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            description?: string | undefined;
            name?: string | undefined;
            price?: string | undefined;
            facets?: {
                name: string;
                options: string[] | null;
            }[] | undefined;
            application: string;
            sku: string;
            title: string;
            image: string;
            _id: string;
        }, {
            description?: string | undefined;
            name?: string | undefined;
            price?: string | undefined;
            facets?: {
                name: string;
                options: string[] | null;
            }[] | undefined;
            application: string;
            sku: string;
            title: string;
            image: string;
            _id: string;
        }>;
    }, "strip", z.ZodTypeAny, {
        product: {
            description?: string | undefined;
            name?: string | undefined;
            price?: string | undefined;
            facets?: {
                name: string;
                options: string[] | null;
            }[] | undefined;
            application: string;
            sku: string;
            title: string;
            image: string;
            _id: string;
        };
    }, {
        product: {
            description?: string | undefined;
            name?: string | undefined;
            price?: string | undefined;
            facets?: {
                name: string;
                options: string[] | null;
            }[] | undefined;
            application: string;
            sku: string;
            title: string;
            image: string;
            _id: string;
        };
    }>>;
    scene: z.ZodIntersection<z.ZodIntersection<z.ZodObject<{
        title: z.ZodString;
        subtitle: z.ZodOptional<z.ZodString>;
        previewImage: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        subtitle?: string | undefined;
        previewImage?: string | undefined;
        title: string;
    }, {
        subtitle?: string | undefined;
        previewImage?: string | undefined;
        title: string;
    }>, z.ZodObject<{
        name: z.ZodString;
        subSelection: z.ZodOptional<z.ZodObject<{
            name: z.ZodString;
            title: z.ZodOptional<z.ZodString>;
            previewImage: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            title?: string | undefined;
            previewImage?: string | undefined;
            name: string;
        }, {
            title?: string | undefined;
            previewImage?: string | undefined;
            name: string;
        }>>;
    }, "strip", z.ZodTypeAny, {
        subSelection?: {
            title?: string | undefined;
            previewImage?: string | undefined;
            name: string;
        } | undefined;
        name: string;
    }, {
        subSelection?: {
            title?: string | undefined;
            previewImage?: string | undefined;
            name: string;
        } | undefined;
        name: string;
    }>>, z.ZodObject<{
        experienceId: z.ZodString;
        sceneId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        experienceId: string;
        sceneId: string;
    }, {
        experienceId: string;
        sceneId: string;
    }>>;
}, "strip", z.ZodTypeAny, {
    image: string;
    scene: {
        subtitle?: string | undefined;
        previewImage?: string | undefined;
        title: string;
    } & {
        subSelection?: {
            title?: string | undefined;
            previewImage?: string | undefined;
            name: string;
        } | undefined;
        name: string;
    } & {
        experienceId: string;
        sceneId: string;
    };
    favorites: {
        product: {
            description?: string | undefined;
            name?: string | undefined;
            price?: string | undefined;
            facets?: {
                name: string;
                options: string[] | null;
            }[] | undefined;
            application: string;
            sku: string;
            title: string;
            image: string;
            _id: string;
        };
    }[];
    id: string;
}, {
    image: string;
    scene: {
        subtitle?: string | undefined;
        previewImage?: string | undefined;
        title: string;
    } & {
        subSelection?: {
            title?: string | undefined;
            previewImage?: string | undefined;
            name: string;
        } | undefined;
        name: string;
    } & {
        experienceId: string;
        sceneId: string;
    };
    favorites: {
        product: {
            description?: string | undefined;
            name?: string | undefined;
            price?: string | undefined;
            facets?: {
                name: string;
                options: string[] | null;
            }[] | undefined;
            application: string;
            sku: string;
            title: string;
            image: string;
            _id: string;
        };
    }[];
    id: string;
}>;
export declare const iFavoriteSceneListSchema: z.ZodArray<z.ZodObject<{
    id: z.ZodString;
    image: z.ZodString;
    favorites: z.ZodArray<z.ZodObject<{
        product: z.ZodObject<{
            sku: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
            title: z.ZodString;
            description: z.ZodOptional<z.ZodString>;
            application: z.ZodString;
            image: z.ZodString;
            price: z.ZodOptional<z.ZodString>;
            facets: z.ZodOptional<z.ZodArray<z.ZodObject<{
                name: z.ZodString;
                options: z.ZodUnion<[z.ZodArray<z.ZodString>, z.ZodNull]>;
            }, "strip", z.ZodTypeAny, {
                name: string;
                options: string[] | null;
            }, {
                name: string;
                options: string[] | null;
            }>>>;
            _id: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            description?: string | undefined;
            name?: string | undefined;
            price?: string | undefined;
            facets?: {
                name: string;
                options: string[] | null;
            }[] | undefined;
            application: string;
            sku: string;
            title: string;
            image: string;
            _id: string;
        }, {
            description?: string | undefined;
            name?: string | undefined;
            price?: string | undefined;
            facets?: {
                name: string;
                options: string[] | null;
            }[] | undefined;
            application: string;
            sku: string;
            title: string;
            image: string;
            _id: string;
        }>;
    }, "strip", z.ZodTypeAny, {
        product: {
            description?: string | undefined;
            name?: string | undefined;
            price?: string | undefined;
            facets?: {
                name: string;
                options: string[] | null;
            }[] | undefined;
            application: string;
            sku: string;
            title: string;
            image: string;
            _id: string;
        };
    }, {
        product: {
            description?: string | undefined;
            name?: string | undefined;
            price?: string | undefined;
            facets?: {
                name: string;
                options: string[] | null;
            }[] | undefined;
            application: string;
            sku: string;
            title: string;
            image: string;
            _id: string;
        };
    }>>;
    scene: z.ZodIntersection<z.ZodIntersection<z.ZodObject<{
        title: z.ZodString;
        subtitle: z.ZodOptional<z.ZodString>;
        previewImage: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        subtitle?: string | undefined;
        previewImage?: string | undefined;
        title: string;
    }, {
        subtitle?: string | undefined;
        previewImage?: string | undefined;
        title: string;
    }>, z.ZodObject<{
        name: z.ZodString;
        subSelection: z.ZodOptional<z.ZodObject<{
            name: z.ZodString;
            title: z.ZodOptional<z.ZodString>;
            previewImage: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            title?: string | undefined;
            previewImage?: string | undefined;
            name: string;
        }, {
            title?: string | undefined;
            previewImage?: string | undefined;
            name: string;
        }>>;
    }, "strip", z.ZodTypeAny, {
        subSelection?: {
            title?: string | undefined;
            previewImage?: string | undefined;
            name: string;
        } | undefined;
        name: string;
    }, {
        subSelection?: {
            title?: string | undefined;
            previewImage?: string | undefined;
            name: string;
        } | undefined;
        name: string;
    }>>, z.ZodObject<{
        experienceId: z.ZodString;
        sceneId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        experienceId: string;
        sceneId: string;
    }, {
        experienceId: string;
        sceneId: string;
    }>>;
}, "strip", z.ZodTypeAny, {
    image: string;
    scene: {
        subtitle?: string | undefined;
        previewImage?: string | undefined;
        title: string;
    } & {
        subSelection?: {
            title?: string | undefined;
            previewImage?: string | undefined;
            name: string;
        } | undefined;
        name: string;
    } & {
        experienceId: string;
        sceneId: string;
    };
    favorites: {
        product: {
            description?: string | undefined;
            name?: string | undefined;
            price?: string | undefined;
            facets?: {
                name: string;
                options: string[] | null;
            }[] | undefined;
            application: string;
            sku: string;
            title: string;
            image: string;
            _id: string;
        };
    }[];
    id: string;
}, {
    image: string;
    scene: {
        subtitle?: string | undefined;
        previewImage?: string | undefined;
        title: string;
    } & {
        subSelection?: {
            title?: string | undefined;
            previewImage?: string | undefined;
            name: string;
        } | undefined;
        name: string;
    } & {
        experienceId: string;
        sceneId: string;
    };
    favorites: {
        product: {
            description?: string | undefined;
            name?: string | undefined;
            price?: string | undefined;
            facets?: {
                name: string;
                options: string[] | null;
            }[] | undefined;
            application: string;
            sku: string;
            title: string;
            image: string;
            _id: string;
        };
    }[];
    id: string;
}>>;
export declare const iFavoriteProductListSchema: z.ZodArray<z.ZodObject<{
    product: z.ZodObject<{
        sku: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
        title: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        application: z.ZodString;
        image: z.ZodString;
        price: z.ZodOptional<z.ZodString>;
        facets: z.ZodOptional<z.ZodArray<z.ZodObject<{
            name: z.ZodString;
            options: z.ZodUnion<[z.ZodArray<z.ZodString>, z.ZodNull]>;
        }, "strip", z.ZodTypeAny, {
            name: string;
            options: string[] | null;
        }, {
            name: string;
            options: string[] | null;
        }>>>;
        _id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        description?: string | undefined;
        name?: string | undefined;
        price?: string | undefined;
        facets?: {
            name: string;
            options: string[] | null;
        }[] | undefined;
        application: string;
        sku: string;
        title: string;
        image: string;
        _id: string;
    }, {
        description?: string | undefined;
        name?: string | undefined;
        price?: string | undefined;
        facets?: {
            name: string;
            options: string[] | null;
        }[] | undefined;
        application: string;
        sku: string;
        title: string;
        image: string;
        _id: string;
    }>;
}, "strip", z.ZodTypeAny, {
    product: {
        description?: string | undefined;
        name?: string | undefined;
        price?: string | undefined;
        facets?: {
            name: string;
            options: string[] | null;
        }[] | undefined;
        application: string;
        sku: string;
        title: string;
        image: string;
        _id: string;
    };
}, {
    product: {
        description?: string | undefined;
        name?: string | undefined;
        price?: string | undefined;
        facets?: {
            name: string;
            options: string[] | null;
        }[] | undefined;
        application: string;
        sku: string;
        title: string;
        image: string;
        _id: string;
    };
}>>;
export declare const iFavoriteProductSkuAndApplicationListSchema: z.ZodArray<z.ZodObject<{
    product: z.ZodObject<{
        sku: z.ZodString;
        application: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        application: string;
        sku: string;
    }, {
        application: string;
        sku: string;
    }>;
}, "strip", z.ZodTypeAny, {
    product: {
        application: string;
        sku: string;
    };
}, {
    product: {
        application: string;
        sku: string;
    };
}>>;
